@@ -29,7 +29,7 @@ pub struct CacheEntry {
     pub info: PkgInfo,
 }
 
-fn is_compatible(debversion: &str, crateversion: &VersionReq) -> Result<bool, Error> {
+fn parse_deb_version(debversion: &str) -> Result<Version> {
     let mut debversion = debversion.replace('~', "-");
     if let Some((version, _suffix)) = debversion.split_once('+') {
         debversion = match version.matches('.').count() {
@@ -40,7 +40,11 @@ fn is_compatible(debversion: &str, crateversion: &VersionReq) -> Result<bool, Er
         };
     }
     let debversion = Version::parse(&debversion)?;
+    Ok(debversion)
+}
 
+fn is_compatible(debversion: &str, crateversion: &VersionReq) -> Result<bool, Error> {
+    let debversion = parse_deb_version(debversion)?;
     Ok(crateversion.matches(&debversion))
 }
 
@@ -98,7 +102,7 @@ impl Connection {
         if SystemTime::now().duration_since(cache.from)? > CACHE_EXPIRE {
             Ok(None)
         } else {
-            debug!("{package} {:?}", cache.info);
+            debug!("Found package in cache: {package} -> {:?}", cache.info);
             Ok(Some(cache.info))
         }
     }
@@ -119,9 +123,16 @@ impl Connection {
         Ok(())
     }
 
-    pub fn search(&mut self, package: &str, version: &Version) -> Result<PkgInfo, Error> {
-        if let Some(info) = self.check_cache("sid", package, version)? {
-            return Ok(info);
+    pub fn search(
+        &mut self,
+        package: &str,
+        version: &Version,
+        skip_cache: bool,
+    ) -> Result<PkgInfo, Error> {
+        if !skip_cache {
+            if let Some(info) = self.check_cache("sid", package, version)? {
+                return Ok(info);
+            }
         }
 
         // config.shell().status("Querying", format!("sid: {}", package))?;
@@ -136,9 +147,16 @@ impl Connection {
         Ok(info)
     }
 
-    pub fn search_new(&mut self, package: &str, version: &Version) -> Result<PkgInfo, Error> {
-        if let Some(info) = self.check_cache("new", package, version)? {
-            return Ok(info);
+    pub fn search_new(
+        &mut self,
+        package: &str,
+        version: &Version,
+        skip_cache: bool,
+    ) -> Result<PkgInfo, Error> {
+        if !skip_cache {
+            if let Some(info) = self.check_cache("new", package, version)? {
+                return Ok(info);
+            }
         }
 
         // config.shell().status("Querying", format!("new: {}", package))?;
@@ -164,6 +182,7 @@ impl Connection {
             version: String::new(),
         };
         let package = package.replace('_', "-");
+        let package = package.to_lowercase();
         let semver_version = if version.major == 0 {
             if version.minor == 0 {
                 format!("{}.{}.{}", version.major, version.minor, version.patch)
@@ -205,6 +224,15 @@ impl Connection {
             } else if info.status == PkgStatus::NotFound {
                 info.version = debversion.to_string();
                 info.status = PkgStatus::Outdated;
+            } else if info.status == PkgStatus::Outdated {
+                if let (Ok(existing), Ok(ours)) = (
+                    parse_deb_version(&info.version),
+                    parse_deb_version(debversion),
+                ) {
+                    if existing < ours {
+                        info.version = debversion.to_string();
+                    }
+                }
             }
         }
 
